@@ -13,6 +13,7 @@ use NewsExtractor::SiteSpecificExtractor::www_rvn_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_allnews_tw;
 use NewsExtractor::SiteSpecificExtractor::www_peopo_org;
 use NewsExtractor::SiteSpecificExtractor::www_ntdtv_com;
+use NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw;
 
 has extractor => (
     required => 0,
@@ -34,8 +35,15 @@ use constant {
         'www.ctwant.com' => 'NewsExtractor::JSONLDExtractor',
         'www.peopo.org' => 'NewsExtractor::SiteSpecificExtractor::www_peopo_org',
         'www.ntdtv.com' => 'NewsExtractor::SiteSpecificExtractor::www_ntdtv_com',
+        'www.ksnews.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw',
     },
     CSSRuleSetByHost => {
+        'www.nownews.com' => {
+            headline   => 'h1.entry-title',
+            dateline   => 'span.td-post-date:nth-child(2) > time:nth-child(1)',
+            journalist => '.td-post-author-name',
+            content_text => '.td-post-content > span[itemprop=articleBody]',
+        },
         'www.epochtimes.com' => {
             headline     => 'h1.title',
             dateline     => 'header[role=heading] time[datetime]',
